@@ -4,7 +4,7 @@ package Test::Class::Moose::Role::Executor;
 
 use 5.10.0;
 
-our $VERSION = '0.72';
+our $VERSION = '0.73';
 
 use Moose::Role 2.0000;
 use Carp;
@@ -12,7 +12,7 @@ use namespace::autoclean;
 
 use List::SomeUtils qw(uniq);
 use List::Util qw(shuffle);
-use Test2::API qw( context context_do test2_stack );
+use Test2::API qw( test2_stack );
 use Test2::Tools::AsyncSubtest qw( async_subtest );
 use Test::Class::Moose::AttributeRegistry;
 use Test::Class::Moose::Config;
@@ -20,6 +20,7 @@ use Test::Class::Moose::Report::Class;
 use Test::Class::Moose::Report::Instance;
 use Test::Class::Moose::Report::Method;
 use Test::Class::Moose::Report;
+use Test::Class::Moose::Util qw( context_do );
 use Try::Tiny;
 
 has 'test_configuration' => (
@@ -515,7 +516,7 @@ Test::Class::Moose::Role::Executor - Common code for Runner classes
 
 =head1 VERSION
 
-version 0.72
+version 0.73
 
 =for Pod::Coverage runtests test_classes
 
